const express = require('express');
const mongoose = require('mongoose');
const yaml = require('js-yaml')
const fs = require('fs')

const app = express();

app.use(express.json());

// Fetch values for MongoDB connections string from YAML file
let MONGODB_USERNAME = process.env.MONGODB_USERNAME;
let MONGODB_PASSWORD = process.env.MONGODB_PASSWORD;
let MONGODB_CONTAINER_NAME = process.env.MONGODB_CONTAINER_NAME;
let MONGODB_CONTAINER_PORT = process.env.MONGODB_CONTAINER_PORT;

const mongoURI = 'mongodb://' + MONGODB_USERNAME + ':' + MONGODB_PASSWORD + '@' + MONGODB_CONTAINER_NAME + ':' + MONGODB_CONTAINER_PORT



mongoose.connect(mongoURI)
.then(() => {
    console.log('Connected to MongoDB');
})
.catch((err) => {
    console.error('Error connecting to MongoDB:', err);
});


const userSchema = new mongoose.Schema({
    name: { type: String, required: true },
    age: { type: Number, required: true },
});

const User = mongoose.model('Users', userSchema, 'users');

app.get('/', async (req, res) => {
    res.send("Express server is running");
});

app.get('/users', async (req, res) => {
    try {
        const users = await User.find();
        res.json(users);
    } catch (error) {
        res.status(500).json({ error: error.message });
    }
});


app.listen(3000, () => {
    console.log(`Server started at http://localhost:3000`);
});


